---
name: Documentation request
about: Describe this issue template's purpose here.
title: ''
labels: documentation
assignees: ''

---

1. What kind of documentation do you want changed? Readme? Docs?
2. What line do want changed or what addition do you feel like is needed?
